
=========================
Tools & Related Tutorials
=========================

PyTorch
=======

* `Github <https://github.com/pytorch/pytorch>`_ and `Document <http://pytorch.org/>`_
* PyTorch Tutorial `Github <https://github.com/pytorch/tutorials>`_ and `Doc <http://pytorch.org/tutorials/>`_
* PyTorch Examples `Github <https://github.com/pytorch/examples>`_

Theano
======

* `Github <https://github.com/Theano/Theano/>`_ and `Document <http://deeplearning.net/software/theano/>`_
* `Deep Learning Tutorial Document <http://deeplearning.net/tutorial/>`_ and `Deep Learning Tutorial Github <https://github.com/lisa-lab/DeepLearningTutorials>`_
* `theano tutorial <http://www.marekrei.com/blog/theano-tutorial/>`_
* `IPython Theano Tutorials <https://github.com/jaberg/IPythonTheanoTutorials>`_
* `IPython Theano Tutorials 2 <https://github.com/craffel/theano-tutorial/blob/master/Theano%20Tutorial.ipynb>`_
* `Theano Official Tutorial <http://deeplearning.net/software/theano/tutorial/>`_
* `Awesome pytorch list <https://github.com/bharathgs/Awesome-pytorch-list>`_

TensorFlow
==========

* `Github <https://github.com/tensorflow>`_ and `Document <https://www.tensorflow.org/>`_
* `TensorFlow Tutorial codes <https://github.com/nlintz/TensorFlow-Tutorials>`_
* `TensorFlow Tutorial2 codes <https://github.com/Hvass-Labs/TensorFlow-Tutorials>`_
* `TensorFlow Examples codes <https://github.com/aymericdamien/TensorFlow-Examples>`_

Lasagne
=======

* `Github <https://github.com/Lasagne/Lasagne>`_ and `Document <http://lasagne.readthedocs.io/en/latest/>`_
* `Lasagne ipynb tutorial <https://github.com/craffel/Lasagne-tutorial/blob/master/examples/tutorial.ipynb>`_
* `Theano and Lasagne ipynb Tutotials <https://github.com/ebenolson/pydata2015>`_
*  `Lasagne Recipes (examples) <https://github.com/Lasagne/Recipes>`_

Keras
=====

* `Github <https://github.com/fchollet/keras/tree/master/keras>`_ and `Document <https://keras.io/>`_
* `Keras Examples <https://github.com/fchollet/keras/tree/master/examples>`_
* `Keras Resources <https://github.com/fchollet/keras-resources>`_

Numpy
=====

* `NumpyDL <https://github.com/oujago/NumpyDL>`_
* `python-neural-network <https://github.com/jorgenkg/python-neural-network>`_
* `pybrain <https://github.com/pybrain/pybrain>`_
* `neurolab <https://github.com/zueve/neurolab>`_
* `pyrenn <https://github.com/yabata/pyrenn>`_
* `nnet <https://github.com/andersbll/nnet>`_

Others
======

* `Kur: Descriptive Deep Learning <https://github.com/deepgram/kur>`_. Design, train, and evaluate
  models without ever needing to code.
* `应该选择TensorFlow还是Theano？ <https://www.zhihu.com/question/41907061>`_
* `DL框架的未来发展，TensorFlow/MXNet/Torch, 选哪个？ <https://www.zhihu.com/question/46587833>`_
* `lasagne，keras，pylearn2，nolearn深度学习库，到底哪家强？ <https://www.zhihu.com/question/38648428>`_

